========
pyticoop
========


.. image:: https://img.shields.io/pypi/v/pyticoop.svg
        :target: https://pypi.python.org/pypi/pyticoop

.. image:: https://gitlab.com/ticoop/pyticoop/badges/main/pipeline.svg
        :target: https://gitlab.com/ticoop/pyticoop/-/pipelines
        :alt: Pipeline Status

.. image:: https://img.shields.io/badge/docs-GitLab_Wiki-blue?label=wiki
        :target: https://gitlab.com/ticoop/pyticoop/-/wikis/home
        :alt: Static Badge

Composants Python réutilisables.


* Free software: GNU General Public License v3
* Documentation (en construction): https://gitlab.com/ticoop/pyticoop/-/wikis/home.


Features
--------

* `Module Dolibarr <https://gitlab.com/ticoop/pyticoop/-/tree/main/src/pyticoop/dolibarr>`_: Une couche d'abstraction pour interagir avec l'API Dolibarr, simplifiant l'intégration avec les systèmes Dolibarr.

Déploiement
-----------

Pour déployer sur PyPI:

1. Créer un tag avec le format suivat : ``vx.x.x`` (e.g., ``v1.2.3``)
2. Pousser le tag pour déclencher la pipeline de déploiement


Crédits
-------

Ce package a été créé avec Cookiecutter_ et le template `audreyr/cookiecutter-pypackage`_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage